@@ -57,11 +57,13 @@ class Index():
     """
     def __init__(self):
         LOG.info('start ximalayabox...')
-        self._init_curses()
         # 显示参数
         self._x = 10  #起点x
         self._y = 5  #起点y
         self.weight = 60  # 宽度
+        self.height = 31
+
+        self._init_curses()
 
         self.islogin = False
         self.storage = Storage()
@@ -69,7 +71,6 @@ class Index():
         # 正在播放的章节对象
         self.current_play = self.storage.current_play
 
-        self._set_cookie()
         self._valid_login()
 
         # 选择的菜单项编号
@@ -100,32 +101,23 @@ class Index():
         # 分页类型: 0 -> history; 1 -> track 分页类型不同，所调用的获取下一页内容方法不同
         self.page_type = 0
 
+        # 是否登录中
+        self.logining = False
+        self.logining_cursor = 3
+
     def _init_player(self):
         LOG.debug('init vlc player')
         self.player = Player()
+        LOG.debug('set vlc volume: %s' % self.storage.volume)
         # 新建vlc对象后在未播放前都获取的音量均为0，从之前的记录中获取并设置
         self.player.set_volume(self.storage.volume)
+        LOG.debug('set vlc rate: %s' % self.storage.rate)
+        self.player.set_rate(self.storage.rate)
         self.player.add_callback(vlc.EventType.MediaPlayerEndReached,
                                  self.play_next_cb)
         self.player.add_callback(vlc.EventType.MediaPlayerPositionChanged,
                                  self.update_time)
 
-    def _set_cookie(self, cookie=None):
-        if cookie:
-            self.storage.cookie = cookie
-            self.storage.save()
-            return
-        tmp_cookie_file = '/tmp/_xmla_cookie'
-        if self.storage.cookie:
-            return
-        if not os.path.exists(tmp_cookie_file):
-            return
-        with open(tmp_cookie_file, 'r') as f:
-            cookie = f.read().strip()
-            LOG.debug('discover tmp cookie file, set cookie: %s' % cookie)
-            self.storage.cookie = cookie
-            self.storage.save()
-
     def _valid_login(self):
         LOG.debug('get cookie: %s' % self.storage.cookie)
         if self.storage.cookie:
@@ -146,6 +138,7 @@ class Index():
                     if self.current_play.cursor < 19 else 0
             # 音量
             self.storage.volume = self.player.get_volume()
+            self.storage.rate = self.player.get_rate()
 
             time.sleep(1)
 
@@ -162,6 +155,11 @@ class Index():
         self.current_play.time = self.player.get_time()
         self.current_play.position = self.player.get_position()
 
+    def _adjust_postion(self):
+        height, width = self.screen.getmaxyx()
+        self._x = (width // 2 - self.weight // 2) - 1
+        self._y = height // 2 - self.height // 2
+
     def _init_curses(self):
         # 初始化一个终端
         self.screen = curses.initscr()
@@ -204,6 +202,7 @@ class Index():
             return
         self.storage.current_paly = self.current_play
         self.storage.volume = self.player.get_volume()
+        self.storage.rate = self.player.get_rate()
         self.storage.save()
         LOG.debug('successfully saved the current play object to history file')
         #TODO: 未生效
@@ -244,8 +243,10 @@ class Index():
             self._display_help()
         if self.isexit:
             self._display_exit_window()
-        self._display_pagination()
-        self._display_player()
+
+        if self.islogin:
+            self._display_pagination()
+            self._display_player()
 
     def _display_comment(self):
         x = self._x + 5
@@ -264,8 +265,11 @@ class Index():
     def _display_menu(self):
         x = self._x + 5
         y = copy.deepcopy(self._y + 7)
-        # 每页个数
-        num = 10
+
+        # 登录中
+        if self.logining:
+            self.display_info('登录中%s' % ('.' * self.logining_cursor), x, y)
+            return
 
         if not len(self.current_items):
             self.display_info('什么都没有~~', x, y)
@@ -301,7 +305,9 @@ class Index():
                 '$ %s' % get_pretty_str(play_display_name, cursor, max_len), x,
                 y, 5)
 
-        self.display_info('[音量: %s]' % self.storage.volume, 54, y, 5)
+        self.display_info('[速率: %s]' % round(self.storage.rate, 1), x + 42,
+                          y - 1, 5)
+        self.display_info('[音量: %s]' % self.storage.volume, x + 42, y, 5)
         self.display_info(
             '[%s%s][%s/%s]' %
             ('=' * play_progress_bar_len, '-' *
@@ -319,8 +325,8 @@ class Index():
         self.display_info('-' * 26, x, y + 4, 3)
 
     def _display_help(self):
-        x = self._x + 20
-        y = self._y + 7
+        x = self._x + 27
+        y = self._y + 6
         self.display_info('-' * 27, x, y, 5)
         self.display_info('|%s?%s%s%s|' % (' ' * 9, ' ' * 5, '帮助', ' ' * 6), x,
                           y + 1, 5)
@@ -331,26 +337,29 @@ class Index():
                           x, y + 3, 5)
         self.display_info('|%s-%s%s%s|' % (' ' * 9, ' ' * 5, '音量减小', ' ' * 2),
                           x, y + 4, 5)
+        self.display_info('|%s+%s%s%s|' % (' ' * 9, ' ' * 5, '速率增加', ' ' * 2),
+                          x, y + 5, 5)
+        self.display_info('|%s-%s%s%s|' % (' ' * 9, ' ' * 5, '速率减小', ' ' * 2),
+                          x, y + 6, 5)
         self.display_info('|%s>%s%s%s|' % (' ' * 9, ' ' * 5, '快进', ' ' * 6), x,
-                          y + 5, 5)
-        self.display_info('|%s<%s%s%s|' % (' ' * 9, ' ' * 5, '快退', ' ' * 6), x,
-                          y + 6, 5)
-        self.display_info('|%sq%s%s%s|' % (' ' * 9, ' ' * 5, '退出', ' ' * 6), x,
                           y + 7, 5)
-        self.display_info('-' * 27, x, y + 8, 5)
+        self.display_info('|%s<%s%s%s|' % (' ' * 9, ' ' * 5, '快退', ' ' * 6), x,
+                          y + 8, 5)
+        self.display_info('|%sq%s%s%s|' % (' ' * 9, ' ' * 5, '退出', ' ' * 6), x,
+                          y + 9, 5)
+        self.display_info('-' * 27, x, y + 10, 5)
 
     def display_footer(self):
-        '''
-        <key>   <log>
-        '''
         x = self._x
         y = self._y + 25
         self.display_info('-' * self.weight, x, y)
-        self.display_info('select: %s' % self.key, x, y + 1, 1)
+        self.display_info('key: %s' % self.key, x, y + 1, 1)
         log_tmp_x = x + self.weight - wcswidth(self.log_string)
         self.display_info(self.log_string, log_tmp_x, y + 1, 1)
 
     def _pre_page(self):
+        if self.current_meun_type == 0:
+            return
         LOG.debug('skip to previous page')
         if self.page_num == 1:
             self.log_string = '已经是第一页'
@@ -362,6 +371,8 @@ class Index():
                 self.display_chapter_list(self.select_item, True)
 
     def _next_page(self):
+        if self.current_meun_type == 0:
+            return
         LOG.debug('skip to next page')
         if self.page_num == self.pages:
             self.log_string = '已经是最后一页'
@@ -379,6 +390,8 @@ class Index():
             self.screen.clrtobot()
             curses.noecho()
 
+            self._adjust_postion()
+
             self.display_header()
             self.display_body()
             self.display_footer()
@@ -470,6 +483,14 @@ class Index():
                 if self.storage.volume > 0:
                     self.player.set_volume(self.storage.volume - 2)
 
+            # 速率
+            elif key == ord(')') or key == 41:
+                if self.storage.rate < 3:
+                    self.player.set_rate(self.storage.rate + 0.1)
+            elif key == ord('(') or key == 40:
+                if self.storage.rate > 0:
+                    self.player.set_rate(self.storage.rate - 0.1)
+
             # 快进/快退
             elif key == 261:
                 self.player.set_time(self.current_play.time + 3)
@@ -483,7 +504,8 @@ class Index():
     def user_logout(self):
         self.islogin = False
         self.user = User(None)
-        self._set_cookie(None)
+        self.storage.cookie = None
+        self.storage.save()
         self.menu_stack.top = {'type': 0, 'items': LOGOUTED_ITEMS}
         self.select_index = 0
 
@@ -491,12 +513,17 @@ class Index():
         _thread.start_new_thread(self._login, ())
 
     def _login(self):
-        cookie = Brower().get_cookie()
-        self._set_cookie(cookie)
-        self._valid_login()
-        if self.islogin:
-            self.menu_stack.top = {'type': 0, 'items': LOGINED_ITEMS}
-            self.select_index = 0
+        self.logining = True
+        try:
+            cookie = Brower().get_cookie(self)
+            self.storage.cookie = cookie
+            self.storage.save()
+            self._valid_login()
+            if self.islogin:
+                self.menu_stack.top = {'type': 0, 'items': LOGINED_ITEMS}
+                self.select_index = 0
+        finally:
+            self.logining = False
 
     def display_collect_list(self):
         """显示收藏列表"""
