@@ -5,7 +5,7 @@ import logging
 from xmlabox.base import Track
 
 LOG = logging.getLogger(__name__)
-content = {'cookie': None, 'current_play': None, 'volume': 0}
+content = {'cookie': None, 'current_play': None, 'volume': 0, 'rate': 1.0}
 default_path = os.path.join(os.getenv('HOME'), '.xmlabox/xmla.json')
 
 
@@ -29,6 +29,7 @@ class Storage:
             self._cookie = stor.get('cookie')
             self._current_paly = stor.get('current_play')
             self._volume = stor.get('volume')
+            self._rate = stor.get('rate')
 
     def save(self):
         with open(self.file_path, 'w') as f:
@@ -36,7 +37,8 @@ class Storage:
                 json.dumps({
                     'cookie': self._cookie,
                     'current_play': self._current_paly,
-                    'volume': self._volume
+                    'volume': self._volume,
+                    'rate': self._rate
                 }))
 
     @property
@@ -63,4 +65,12 @@ class Storage:
 
     @volume.setter
     def volume(self, volume):
-        self._volume = volume
\ No newline at end of file
+        self._volume = volume
+
+    @property
+    def rate(self):
+        return self._rate
+
+    @rate.setter
+    def rate(self, rate):
+        self._rate = rate
